/* Minuterie analogique:
	entrée par potentiomètre, affichage par un servomoteur
	Module digispark
	IDE: https://gist.github.com/Ircama/22707e938e9c8f169d9fe187797a2a2c
	http://digistump.com/wiki/digispark/tutorials/connecting#software
*/

#include <SoftRcPulseOut.h>
/* 
void setMinimumPulse(uint16_t);  // pulse length for 0 degrees in microseconds, 540uS default
void setMaximumPulse(uint16_t); // pulse length for 180 degrees in microseconds, 2400uS default 
*/
 
/* Caractéristiques des broches du Digispark
Entrees Analogiques 0=PB5; 1=PB2; 2=PB4; 3=PB3
Sorties PWM: P0; P1; P4
Diode LED sur PB1
*/

SoftRcPulseOut myservo;  // create servo object to control a servo 

#define angle_mini 0
#define angle_maxi 180
#define calibre_Sec 300   // Echelle 5 minutes

int potpin = 1;  // Entrée analogique A1 = Broche PB2: potentiomètre

void setup() 
{ 
  myservo.attach(0);	// attaches the servo on pin 0 to the servo object 
  myservo.setMaximumPulse(2400);
  myservo.setMinimumPulse(540);
  pinMode(1, OUTPUT);	// P1: sortie pour sonnerie	
} 

void loop() { 
	 digitalWrite(1,LOW);
	 unsigned long val_pot = analogRead(potpin); 
	 
	 /* 
	minuterie(ms)= val_pot * calibre_Sec * 1000 / 1024  pour mouvement de 0 à 180°
	refresh toutes les 20ms
	T_Ref= val_pot * 1000 / 20 / 1024   = n_b_p: nombre de pas (de 20ms) à effectuer 
	nombre de pas par degrés n_par_deg= n_b_p / (angle_maxi-angle_mini)
	 */
	 
	 unsigned long T_Ref = calibre_Sec * 50 * val_pot /1024;
	 int n_b_p =(int)T_Ref;
	 int n_par_deg= n_b_p / (angle_maxi-angle_mini);
	 int angle = angle_mini;	// angle de départ
	 int compteur = 0;			// compteur de pas par degré
	 
	 for (int n=0; n<=n_b_p; n++){
			if (compteur >= n_par_deg){  // comptage des pas / degrés
				compteur = 0;
				angle ++;
				myservo.write(angle);    // nouvelle valeur d'angle
			}
			compteur ++;
			
			while(!SoftRcPulseOut::refresh()); //attente du "refresh" (20 ms )
	 }
	digitalWrite(1,HIGH);
	while(true); // sonnerie
} 
